@@ -20,6 +20,7 @@ from .character_dictionaries import CYR_TO_LAT_TTABLE
 from .character_dictionaries import LAT_TO_CYR_DICT
 from .character_dictionaries import LAT_TO_CYR_DIGRAPHS_DICT
 from .character_dictionaries import LAT_TO_CYR_TTABLE
+from .cli import main as cli
 from .transliteration import cyrillic_to_latin
 from .transliteration import latin_to_cyrillic
 
@@ -33,4 +34,5 @@ __all__ = (
     "__version__",
     "cyrillic_to_latin",
     "latin_to_cyrillic",
+    "cli",
 )
